#ifndef NEWDB_H
#define NEWDB_H

#include <qdialog.h>

class QComboBox;

class NewDB : public QDialog
{
	Q_OBJECT
	public:
		NewDB(QWidget *parent = NULL, const char *name = NULL);
		~NewDB();

	public slots:
		void slotNewDB();

	signals:
		void signalNewDB(QString type);

	private:
		QComboBox *dbtypes;
};

#endif

